@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,8 +13,7 @@
 #ifndef	BZDBCACHE_H
 #define	BZDBCACHE_H
 
-#include <string>
-
+// implementation headers
 #include "StateDatabase.h"
 
 class BZDBCache
@@ -23,17 +22,38 @@ public:
 	static void init();
 
 	static bool  displayMainFlags;
-	static bool  enhancedRadar;
 	static bool  blend;
-
-	static float maxLOD;
-	static float tankHeight;
-	static float flagRadius;
-	static float tankRadius;
-	static float flagPoleSize;
-	static float flagPoleWidth;
+	static bool  texture;
+	static bool  shadows;
+	static bool  zbuffer;
+	static bool  tesselation;
+	static bool  lighting;
+	static bool  smooth;
+	static bool  colorful;
+	static int   flagChunks;
+	static bool  animatedTreads;
+	static int   radarStyle;
+	static float radarTankPixels;
+	static bool  leadingShotLine;
 	static int   linedRadarShots;
 	static int   sizedRadarShots;
+	static float pulseRate;
+	static float pulseDepth;
+	static bool  showCollisionGrid;
+	static bool  showCullingGrid;
+
+	static float maxLOD;
+	static float worldSize;
+	static float radarLimit;
+	static float gravity;
+	static float tankWidth;
+	static float tankLength;
+	static float tankHeight;
+	static float tankSpeed;
+	static float tankRadius;
+	static float flagRadius;
+	static float flagPoleSize;
+	static float flagPoleWidth;
 
 public:
   /** public method to update cached variable
