@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,50 +18,62 @@
 #define BZF_BASE_BUILDING_H
 
 #include "common.h"
+#include <string>
 #include "Obstacle.h"
 
 class BaseBuilding : public Obstacle {
+
+  friend class ObstacleModifier;
+
   public:
+			BaseBuilding();
 			BaseBuilding(const float *pos, float rotation,
-				const float *size, int _team);
+				     const float *size, int _team);
 			~BaseBuilding();
-    std::string		getType() const;
-    std::string		getClassName(); // const
+
+    Obstacle*	copyWithTransform(const MeshTransform&) const;
+
+    const char*		getType() const;
+    static const char*	getClassName(); // const
+
+    bool		isFlatTop() const;
+
     float		intersect(const Ray &) const;
     void		getNormal(const float *p, float *n) const;
     void		get3DNormal(const float* p, float* n) const;
-    bool		isInside(const float *p, float radius) const;
-    bool		isInside(const float *p, float angle,
-				float halfWidth, float halfBreadth) const;
-    bool		isInside(const float* oldP, float oldAngle,
-				 const float* p, float angle,
-				 float halfWidth, float halfBreadth) const;
-    bool		isCrossing(const float *p, float angle,
-				float halfWidth, float halfBreadth,
-				float *plane) const;
+
+    bool		inCylinder(const float* p, float radius, float height) const;
+    bool		inBox(const float* p, float angle,
+			      float halfWidth, float halfBreadth, float height) const;
+    bool		inMovingBox(const float* oldP, float oldAngle,
+				    const float *newP, float newAngle,
+				    float halfWidth, float halfBreadth, float height) const;
+    bool		isCrossing(const float* p, float angle,
+				   float halfWidth, float halfBreadth, float height,
+				   float* plane) const;
+
     bool		getHitNormal(const float *pos1, float azimuth1,
 				const float *pos2, float azimuth2,
 				float halfWidth, float halfBreadth,
 				float height,
 				float *normal) const;
-    ObstacleSceneNodeGenerator* newSceneNodeGenerator() const;
     void		getCorner(int index, float *pos) const;
     int			getTeam() const;
-    std::string	        userTextures[2];
- private:
-    static std::string	typeName;
-    int team;
-};
 
-class BaseSceneNodeGenerator : public ObstacleSceneNodeGenerator {
-  friend class BaseBuilding;
-			~BaseSceneNodeGenerator();
-  public:
-    WallSceneNode*	getNextNode(float, float, bool);
-  protected:
-			BaseSceneNodeGenerator(const BaseBuilding *);
+    int packSize() const;
+    void *pack(void*) const;
+    void *unpack(void*);
+
+    void print(std::ostream& out, const std::string& indent) const;
+
+    std::string		userTextures[2];
+
   private:
-    const BaseBuilding *base;
+    void finalize();
+
+  private:
+    static const char*	typeName;
+    int team;
 };
 
 #endif
