@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,15 +13,14 @@
 #ifndef BZF_BUNDLE_H
 #define BZF_BUNDLE_H
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
-
-#include <string>
-#include <vector>
-#include <map>
+// common header first
 #include "common.h"
 
+// system headers
+#include <map>
+#include <vector>
+#include <string>
+
 typedef std::map<std::string, std::string> BundleStringMap;
 
 class Bundle
