@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,10 +13,14 @@
 #ifndef BZF_CALLBACK_LIST_H
 #define BZF_CALLBACK_LIST_H
 
-#include "common.h"
+// system headers
+#include <utility>
 #include <list>
 #include <map>
 
+// local implementation headers
+#include "common.h"
+
 template <class F>
 class CallbackList {
 public:
@@ -113,7 +117,7 @@ void			CallbackList<F>::doIterate(Callback callback,
     // stop if a callback returns false.
     if (index->first != NULL)
       if (!callback(index->first, index->second, userData))
-        break;
+	break;
   }
 
   // now remove the dummy item
