@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,12 +13,8 @@
 #ifndef BZF_FILE_MANAGER_H
 #define BZF_FILE_MANAGER_H
 
-#ifdef _MSC_VER
-#pragma warning(4:4786)
-#endif
-
-#include <string>
 #include "common.h"
+#include <string>
 #include "bzfio.h"
 #include "Singleton.h"
 
