@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -31,7 +31,7 @@ class FlagWarpSceneNode : public SceneNode {
     GLfloat		getDistance(const GLfloat*) const;
     void		move(const GLfloat pos[3]);
 
-    void		notifyStyleChange(const SceneRenderer&);
+    void		notifyStyleChange();
     void		addRenderNodes(SceneRenderer&);
 
   protected:
@@ -40,7 +40,7 @@ class FlagWarpSceneNode : public SceneNode {
 			FlagWarpRenderNode(const FlagWarpSceneNode*);
 			~FlagWarpRenderNode();
 	void		render();
-	const GLfloat*	getPosition() { return sceneNode->getSphere(); }
+	const GLfloat*	getPosition() const { return sceneNode->getSphere(); }
       private:
 	const FlagWarpSceneNode* sceneNode;
     };
