@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,16 +23,18 @@ class BzfDisplay;
 class BzfVisual;
 class BzfWindow;
 class BzfMedia;
+class BzfJoystick;
 
 class PlatformFactory {
   public:
 			PlatformFactory();
     virtual		~PlatformFactory();
 
-    virtual BzfDisplay*	createDisplay(const char* name,
+    virtual BzfDisplay*	 createDisplay(const char* name,
 				const char* videoFormat) = 0;
-    virtual BzfVisual*	createVisual(const BzfDisplay*) = 0;
-    virtual BzfWindow*	createWindow(const BzfDisplay*, BzfVisual*) = 0;
+    virtual BzfVisual*	 createVisual(const BzfDisplay*) = 0;
+    virtual BzfWindow*	 createWindow(const BzfDisplay*, BzfVisual*) = 0;
+    virtual BzfJoystick* createJoystick();
 
     static PlatformFactory*	getInstance();
     static BzfMedia*		getMedia();
