@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -30,7 +30,8 @@ class RenderNode {
     virtual		~RenderNode() { }
 
     virtual void	render() = 0;
-    virtual const GLfloat* getPosition() = 0;
+    virtual void	renderShadow() { render(); }
+    virtual const GLfloat* getPosition() const = 0;
 };
 
 class RenderNodeList {
@@ -55,6 +56,16 @@ class RenderNodeList {
     RenderNode**	list;
 };
 
+inline void RenderNodeList::append(RenderNode* node)
+{
+  if (count == size) {
+    grow();
+  }
+  list[count++] = node;
+}
+
+
+
 class RenderNodeGStateList {
   public:
 			RenderNodeGStateList();
@@ -67,13 +78,7 @@ class RenderNodeGStateList {
 
     void		sort(const GLfloat* eye);
 
-  private:
-    // no copying (cos that'd be slow)
-			RenderNodeGStateList(const RenderNodeGStateList&);
-    RenderNodeGStateList& operator=(const RenderNodeGStateList&);
-
-    void		grow();
-
+    // public for the qsort() comparison function
     struct Item {
       public:
 	typedef const OpenGLGState* GStatePtr;
@@ -82,12 +87,31 @@ class RenderNodeGStateList {
 	float		depth;
     };
 
+  private:
+    // no copying (cos that'd be slow)
+			RenderNodeGStateList(const RenderNodeGStateList&);
+    RenderNodeGStateList& operator=(const RenderNodeGStateList&);
+
+    void		grow();
+
   private:
     int			count;
     int			size;
     Item*		list;
 };
 
+inline void RenderNodeGStateList::append(RenderNode* node,
+					 const OpenGLGState* gstate)
+{
+  if (count == size) {
+    grow();
+  }
+  list[count].node = node;
+  list[count].gstate = gstate;
+  list[count].depth = 0.0f;
+  count++;
+}
+
 #endif // BZF_RENDER_NODE_H
 
 // Local Variables: ***
