@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,14 +13,23 @@
 #ifndef BZADMINCLIENT_H
 #define BZADMINCLIENT_H
 
+/* global interface headers */
+#include "common.h"
+
+/* system interface headers */
 #include <map>
 #include <string>
 
-#include "BZAdminUI.h"
-#include "colors.h"
 #include "PlayerInfo.h"
+#include "colors.h"
 #include "ServerLink.h"
 #include "UIMap.h"
+#include "StartupInfo.h"
+
+
+class BZAdminUI;
+
+extern StartupInfo startupInfo;
 
 /** This class is a client that connects to a BZFlag server and has
     functions for sending and receiving messages. If you give it
@@ -37,11 +46,10 @@ public:
     Superkilled,
     CommError
   };
-  
+
   /** A default constructor. It tries to connect to the server at host:port.
       If it doesn't succeed, calls to isValid() will return false. */
-  BZAdminClient(std::string callsign, std::string host, int port,
-		BZAdminUI* bzInterface = NULL);
+  BZAdminClient(BZAdminUI* bzInterface = NULL);
 
   /** Formats an incoming message. */
   std::string formatMessage(const std::string& msg, PlayerId src, PlayerId dst,
@@ -60,14 +68,11 @@ public:
       in @c str, negative numbers for errors. A color suggestion will be stored
       in @c colorCode.
   */
-  ServerCode getServerString(std::string& str, ColorCode& colorCode);
+  ServerCode checkMessage();
 
-  /** Checks for new packets from the server, ignores them or stores a
-      text message in @c str. Tells @c ui about new or removed players. Returns
-      0 if no interesting packets have arrived, 1 if a message has been stored
-      in @c str, negative numbers for errors.
-  */
-  ServerCode getServerString(std::string& str);
+  /** Returns the std::string that the client built from the last received
+      message. */
+  std::pair<std::string, ColorCode> getLastMessage() const;
 
   /** This function returns @c true if this object has a valid connection
       to a server, @c false if it doesn't. */
@@ -122,17 +127,31 @@ public:
       it - for example, player position updates won't be shown. */
   void showMessageType(std::string type);
 
+  /** This function returns a const reference to the mapping from message type
+      names to message type codes. */
+  const std::map<std::string, uint16_t>& getMessageTypeMap() const;
+
+  /** This function returns the filter status of the message type
+      @c msgType, @c true means "show" and @c false means "hide". */
+  bool getFilterStatus(uint16_t msgType) const;
+
 protected:
 
-  /** This function prints a /set command for the BZDB variable with name 
+  /** This function prints a /set command for the BZDB variable with name
       @c name to the current UI. It assumes that there actually is an UI,
       if @c ui is NULL this function could crash the program. It has to be
       static because it is used as a callback for StateDatabase::iterate(). */
   static void listSetVars(const std::string& name, void* thisObject);
 
+  /** Connects to the list server and gets a list of available servers
+   */
+  void outputServerList() const;
+
+
   PlayerIdMap players;
   TeamColor myTeam;
   ServerLink sLink;
+  std::pair<std::string, ColorCode> lastMessage;
   bool valid;
   std::map<uint16_t, bool> messageMask;
   std::map<TeamColor, ColorCode> colorMap;
