@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -38,7 +38,7 @@ protected:
 
   /** The parameters to this constructor are a map of all players and the
       local player's PlayerId. */
-  CursesUI(const PlayerIdMap& p, PlayerId m);
+  CursesUI(BZAdminClient& c);
 
 public:
 
@@ -47,6 +47,9 @@ public:
   /** This function prints a message in the main window. */
   virtual void outputMessage(const std::string& msg, ColorCode color);
 
+  /** This function is called by the client when a new packet has arrived. */
+  virtual void handleNewPacket(uint16_t msgType);
+
   /** See if the user has entered a command, if it has, store it in str and
       return true. */
   virtual bool checkCommand(std::string& str);
@@ -63,7 +66,7 @@ public:
 
   /** This function returns a pointer to a dynamically allocated
       CursesUI object. */
-  static BZAdminUI* creator(const PlayerIdMap& players, PlayerId me);
+  static BZAdminUI* creator(BZAdminClient& client);
 
 protected:
 
@@ -76,10 +79,10 @@ protected:
       It is useful to do this when the window has been resized (because
       the terminal has been resized, or because the menu has been toggled).
       @param numberOfMessages The last @c numberOfMessages messages from the
-                              buffer will be written to the window.
+			      buffer will be written to the window.
   */
   void updateMainWinFromBuffer(unsigned int numberOfMessages);
-  
+
   /** This function redraws the target window (the line that says who you are
       talking to). */
   void updateTargetWin();
@@ -90,22 +93,22 @@ protected:
 
   /** This function toggles the visibility of the menu window. */
   void toggleMenu();
-  
+
   /** This function sets the menu to the main menu. */
   static void initMainMenu(CursesMenu& menu);
-  
+
   /** This function sets the menu to the player menu. */
   static void initPlayerMenu(CursesMenu& menu);
-  
+
   /** This function sets the menu to the ban menu. */
   static void initBanMenu(CursesMenu& menu);
-  
+
   /** This function sets the menu to the "Set server variables" submenu. */
   static void initServerVarMenu(CursesMenu& menu);
-  
+
   /** Add a single BZDBCMItem to the menu. */
   static void addBZDBCMItem(const std::string& name, void* menu);
-  
+
   /** This function sets the menu to the filter menu. */
   static void initFilterMenu(CursesMenu& menu);
 
@@ -113,25 +116,28 @@ protected:
   WINDOW* targetWin;
   WINDOW* cmdWin;
   WINDOW* menuWin;
-  
-  // 0 = no menu, 1 = menu is visible and handles keystrokes, 2 = menu is
-  // visible but command prompt handles keystrokes
-  int menuState;
+
+  enum {
+    NoMenu,
+    VisibleActive,
+    VisibleInactive
+  } menuState;
   CursesMenu menu;
-  
+
+  BZAdminClient& client;
   std::string cmd;
   const PlayerIdMap& players;
   PlayerIdMap additionalTargets;
   PlayerIdMap::const_iterator targetIter;
   PlayerId me;
-  AutoCompleter comp;
+  DefaultCompleter comp;
   std::vector<std::string> history;
   unsigned int maxHistory;
   unsigned int currentHistory;
   std::vector<std::pair<std::string, ColorCode> > msgBuffer;
   unsigned int maxBufferSize;
   unsigned int scrollOffset;
-  
+
   static UIAdder uiAdder;
 };
 
