@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,7 +19,7 @@
 #include "global.h"
 
 
-/** This struct stores information about a player that is relevant to 
+/** This struct stores information about a player that is relevant to
     bzadmin. */
 struct PlayerInfo {
   PlayerInfo() {}
@@ -30,6 +30,9 @@ struct PlayerInfo {
   int wins;
   int losses;
   int tks;
+  bool isRegistered;
+  bool isVerified;
+  bool isAdmin;
 };
 
 
