@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -20,6 +20,7 @@
 #include <ws2tcpip.h>
 #include <wincon.h>
 #else
+#include <sys/types.h>
 #include <sys/select.h>
 #endif
 
@@ -47,7 +48,7 @@ unsigned long __stdcall winInput(void *that)
 // add this UI to the map
 UIAdder StdBothUI::uiAdder("stdboth", &StdBothUI::creator);
 
-StdBothUI::StdBothUI() : atEOF(false) {
+StdBothUI::StdBothUI(BZAdminClient& c) : BZAdminUI(c), atEOF(false) {
 #ifdef _WIN32
   unsigned long tid;
   console = GetStdHandle(STD_INPUT_HANDLE);
@@ -89,7 +90,7 @@ bool StdBothUI::checkCommand(std::string& str) {
     str = "/quit";
     return true;
   }
-  
+
   static char buffer[MessageLen + 1];
   static int pos = 0;
 
@@ -121,8 +122,8 @@ bool StdBothUI::checkCommand(std::string& str) {
 #endif
 
 
-BZAdminUI* StdBothUI::creator(const PlayerIdMap&, PlayerId) {
-  return new StdBothUI();
+BZAdminUI* StdBothUI::creator(BZAdminClient& client) {
+  return new StdBothUI(client);
 }
 
 // Local Variables: ***
