@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,6 +23,11 @@
 UIAdder StdInUI::uiAdder("stdin", &StdInUI::creator);
 
 
+StdInUI::StdInUI(BZAdminClient& c) : BZAdminUI(c) {
+
+}
+
+
 bool StdInUI::checkCommand(std::string& str) {
   if (std::cin.eof()) {
     str = "/quit";
@@ -35,8 +40,8 @@ bool StdInUI::checkCommand(std::string& str) {
 }
 
 
-BZAdminUI* StdInUI::creator(const PlayerIdMap&, PlayerId) {
-  return new StdInUI();
+BZAdminUI* StdInUI::creator(BZAdminClient& client) {
+  return new StdInUI(client);
 }
 
 // Local Variables: ***
