@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -23,13 +23,18 @@
 UIAdder StdOutUI::uiAdder("stdout", &StdOutUI::creator);
 
 
+StdOutUI::StdOutUI(BZAdminClient& c) : BZAdminUI(c) {
+
+}
+
+
 void StdOutUI::outputMessage(const std::string& msg, ColorCode) {
   std::cout<<msg<<std::endl;
 }
 
 
-BZAdminUI* StdOutUI::creator(const PlayerIdMap&, PlayerId) {
-  return new StdOutUI();
+BZAdminUI* StdOutUI::creator(BZAdminClient& client) {
+  return new StdOutUI(client);
 }
 
 // Local Variables: ***
