@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -25,11 +25,13 @@
 class StdOutUI : public BZAdminUI {
 public:
 
-  void outputMessage(const std::string& msg, ColorCode color);
+  StdOutUI(BZAdminClient& c);
+
+  virtual void outputMessage(const std::string& msg, ColorCode color);
 
   /** This function returns a pointer to a dynamically allocated
       StdOutUI object. */
-  static BZAdminUI* creator(const PlayerIdMap& players, PlayerId me);
+  static BZAdminUI* creator(BZAdminClient&);
 
 protected:
 
