@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,39 +10,48 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifndef	BZF_REMOTE_PLAYER_H
-#define	BZF_REMOTE_PLAYER_H
+#ifndef	__REMOTEPLAYER_H__
+#define	__REMOTEPLAYER_H__
 
 #include "common.h"
+
+/* interface header */
 #include "Player.h"
+
+/* common interface headers */
+#include "global.h"
+#include "ShotUpdate.h"
+
+/* local interface headers */
 #include "ShotPath.h"
 
+
 class RemotePlayer : public Player {
-  public:
-			RemotePlayer(const PlayerId&, TeamColor team,
-					const char* name, const char* email,
-				     const PlayerType);
-			~RemotePlayer();
+public:
+  RemotePlayer(const PlayerId&, TeamColor team,
+	       const char* name, const char* email,
+	       const PlayerType);
+  ~RemotePlayer();
 
-    void		addShot(const FiringInfo&);
-    ShotPath*		getShot(int index) const;
-    void		updateShots(float dt);
+  void addShot(const FiringInfo&);
+  ShotPath* getShot(int index) const;
+  void updateShots(float dt);
 
-  private:
-    bool		doEndShot(int index, bool isHit, float* pos);
+private:
+  bool doEndShot(int index, bool isHit, float* pos);
 
-  private:
-    int			numShots;
-    RemoteShotPath**	shots;
+private:
+  int numShots;
+  RemoteShotPath** shots;
 };
 
-#endif // BZF_REMOTE_PLAYER_H
+
+#endif /* __REMOTE_PLAYER_H__ */
 
 // Local Variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
 // End: ***
 // ex: shiftwidth=2 tabstop=8
-
