@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -16,9 +16,18 @@
 
 //#define SHOOTING_FIX
 
+// bzflag common header
+#include "common.h"
+
+// system headers
 #include <stdlib.h>
 #include <math.h>
-#include "common.h"
+#include <vector>
+
+// common implementation headers
+#include "BZDBCache.h"
+
+// local implementation headers
 #include "World.h"
 #include "RobotPlayer.h"
 #include "RemotePlayer.h"
@@ -26,7 +35,6 @@
 #include "ShotStrategy.h" // need this for rayAtDistanceFromOrigin
 #include "TargetingUtils.h"
 #include "ServerLink.h"
-#include "BZDBCache.h"
 
 std::vector<BzfRegion*>* RobotPlayer::obstacleList = NULL;
 
@@ -73,11 +81,11 @@ void RobotPlayer::projectPosition(const Player *targ,const float t,float &x,floa
     sx = hisspeed * t * cos(rho);
     sy = hisspeed * t * sin(rho);
   }
-  x=hisx+sx;
-  y=hisy+sy;
-  z=hisz+hisvz*t;
+  x=(float)hisx+(float)sx;
+  y=(float)hisy+(float)sy;
+  z=(float)hisz+(float)hisvz*t;
   if (targ->getStatus() & PlayerState::Falling)
-    z += 0.5 * BZDB.eval(StateDatabase::BZDB_GRAVITY) * t * t;
+    z += 0.5f * BZDBCache::gravity * t * t;
   if (z < 0) z = 0;
 }
 
@@ -94,7 +102,7 @@ void RobotPlayer::getProjectedPosition(const Player *targ, float *projpos) const
   double hisy = targ->getPosition()[1];
   double deltax = hisx - myx;
   double deltay = hisy - myy;
-  double distance = hypotf(deltax,deltay) - BZDB.eval(StateDatabase::BZDB_MUZZLEFRONT) - BZDB.eval(StateDatabase::BZDB_TANKRADIUS);
+  double distance = hypotf(deltax,deltay) - BZDB.eval(StateDatabase::BZDB_MUZZLEFRONT) - BZDBCache::tankRadius;
   if (distance <= 0) distance = 0;
   double shotspeed = BZDB.eval(StateDatabase::BZDB_SHOTSPEED)*
     (getFlag() == Flags::Laser ? BZDB.eval(StateDatabase::BZDB_LASERADVEL) :
@@ -106,8 +114,8 @@ void RobotPlayer::getProjectedPosition(const Player *targ, float *projpos) const
   float tx, ty, tz;
   for (int tries=0 ; errdistance > 0.05 && tries < 4 ; tries++)
   {
-    float t = distance / shotspeed;
-    projectPosition(targ, t + 0.05, tx, ty, tz); // add 50ms for lag
+    float t = (float)distance / (float)shotspeed;
+    projectPosition(targ, t + 0.05f, tx, ty, tz); // add 50ms for lag
     double distance2 = hypotf(tx - myx, ty - myy);
     errdistance = fabs(distance2-distance) / (distance + ZERO_TOLERANCE);
     distance = distance2;
@@ -115,7 +123,7 @@ void RobotPlayer::getProjectedPosition(const Player *targ, float *projpos) const
   projpos[0] = tx; projpos[1] = ty; projpos[2] = tz;
 
   // projected pos in building -> use current pos
-  if (World::getWorld()->inBuilding(projpos, 0.0f)) {
+  if (World::getWorld()->inBuilding(projpos, 0.0f, BZDBCache::tankHeight)) {
     projpos[0] = targ->getPosition()[0];
     projpos[1] = targ->getPosition()[1];
     projpos[2] = targ->getPosition()[2];
@@ -127,6 +135,7 @@ void			RobotPlayer::doUpdate(float dt)
 {
   LocalPlayer::doUpdate(dt);
 
+  float tankRadius = BZDBCache::tankRadius;
   const float shotRange  = BZDB.eval(StateDatabase::BZDB_SHOTRANGE);
   const float shotRadius = BZDB.eval(StateDatabase::BZDB_SHOTRADIUS);
 
@@ -138,7 +147,7 @@ void			RobotPlayer::doUpdate(float dt)
   if (getFiringStatus() != Ready)
     return;
 
-  bool        shoot   = false;
+  bool	shoot   = false;
   const float azimuth = getAngle();
   // Allow shooting only if angle is near and timer has elapsed
   if ((int)path.size() != 0 && timerForShot <= 0.0f) {
@@ -147,21 +156,21 @@ void			RobotPlayer::doUpdate(float dt)
     const float* p2     = getPosition();
     float shootingAngle = atan2f(p1[1] - p2[1], p1[0] - p2[0]);
     if (shootingAngle < 0.0f)
-      shootingAngle += 2.0f * M_PI;
+      shootingAngle += (float)(2.0 * M_PI);
     float azimuthDiff   = shootingAngle - azimuth;
     if (azimuthDiff > M_PI)
-      azimuthDiff -= 2.0f * M_PI;
+      azimuthDiff -= (float)(2.0 * M_PI);
     else
       if (azimuthDiff < -M_PI)
-        azimuthDiff += 2.0f * M_PI;
+	azimuthDiff += (float)(2.0 * M_PI);
 
     const float targetdistance = hypotf(p1[0] - p2[0], p1[1] - p2[1]) -
-      BZDB.eval(StateDatabase::BZDB_MUZZLEFRONT) -
-      BZDB.eval(StateDatabase::BZDB_TANKRADIUS);
+      BZDB.eval(StateDatabase::BZDB_MUZZLEFRONT) - tankRadius;
+
     const float missby = fabs(azimuthDiff) *
-      (targetdistance - BZDB.eval(StateDatabase::BZDB_TANKLENGTH));
+      (targetdistance - BZDBCache::tankLength);
     // only shoot if we miss by less than half a tanklength and no building inbetween
-    if (missby < 0.5 * BZDB.eval(StateDatabase::BZDB_TANKLENGTH) &&
+    if (missby < 0.5f * BZDBCache::tankLength &&
 	p1[2] < shotRadius) {
       float pos[3] = {getPosition()[0], getPosition()[1],
 		      getPosition()[2] +  BZDB.eval(StateDatabase::BZDB_MUZZLEHEIGHT)};
@@ -185,7 +194,7 @@ void			RobotPlayer::doUpdate(float dt)
 			     getPosition()[1] - p->getPosition()[1],
 			     getPosition()[2] - p->getPosition()[2]};
 	  Ray ray(relpos, dir);
-	  float impact = rayAtDistanceFromOrigin(ray, 5 * BZDB.eval(StateDatabase::BZDB_TANKRADIUS));
+	  float impact = rayAtDistanceFromOrigin(ray, 5 * BZDBCache::tankRadius);
 	  if (impact > 0 && impact < shotRange)
 	  {
 	    shoot=false;
@@ -215,7 +224,7 @@ void			RobotPlayer::doUpdateMotion(float dt)
     position[2] = oldPosition[2];
     float azimuth = oldAzimuth;
     float tankAngVel = BZDB.eval(StateDatabase::BZDB_TANKANGVEL);
-    float tankSpeed = BZDB.eval(StateDatabase::BZDB_TANKSPEED);
+    float tankSpeed = BZDBCache::tankSpeed;
 
 
     // basically a clone of Roger's evasive code
@@ -223,50 +232,51 @@ void			RobotPlayer::doUpdateMotion(float dt)
     {
       Player *p = 0;
       if (t < World::getWorld()->getCurMaxPlayers())
-        p = World::getWorld()->getPlayer(t);
+	p = World::getWorld()->getPlayer(t);
       else
-        p = LocalPlayer::getMyTank();
+	p = LocalPlayer::getMyTank();
       if (!p || p->getId() == getId())
-        continue;
+	continue;
       const int maxShots = p->getMaxShots();
       for (int s = 0; s < maxShots; s++) {
-        ShotPath* shot = p->getShot(s);
-        if (!shot || shot->isExpired())
-          continue;
-        // ignore invisible bullets completely for now (even when visible)
-        if (shot->getFlag() == Flags::InvisibleBullet)
-          continue;
-        const float* shotPos = shot->getPosition();
-        if ((fabs(shotPos[2] - position[2]) > BZDBCache::tankHeight) && (shot->getFlag() != Flags::GuidedMissile))
-          continue;
-        const float dist = TargetingUtils::getTargetDistance(position, shotPos);
-        if (dist < 150.0f) {
-          const float *shotVel = shot->getVelocity();
-          float shotAngle = atan2f(shotVel[1], shotVel[0]);
-          float shotUnitVec[2] = {cos(shotAngle), sin(shotAngle)};
+	ShotPath* shot = p->getShot(s);
+	if (!shot || shot->isExpired())
+	  continue;
+	// ignore invisible bullets completely for now (even when visible)
+	if (shot->getFlag() == Flags::InvisibleBullet)
+	  continue;
 
-          float trueVec[2] = {(position[0]-shotPos[0])/dist,(position[1]-shotPos[1])/dist};
-          float dotProd = trueVec[0]*shotUnitVec[0]+trueVec[1]*shotUnitVec[1];
+	const float* shotPos = shot->getPosition();
+	if ((fabs(shotPos[2] - position[2]) > BZDBCache::tankHeight) && (shot->getFlag() != Flags::GuidedMissile))
+	  continue;
+	const float dist = TargetingUtils::getTargetDistance(position, shotPos);
+	if (dist < 150.0f) {
+	  const float *shotVel = shot->getVelocity();
+	  float shotAngle = atan2f(shotVel[1], shotVel[0]);
+	  float shotUnitVec[2] = {cos(shotAngle), sin(shotAngle)};
 
-          if (dotProd > 0.97f) {
-            float rotation;
-            float rotation1 = (shotAngle + M_PI/2.0f) - azimuth;
-            if (rotation1 < -1.0f * M_PI) rotation1 += 2.0f * M_PI;
-            if (rotation1 > 1.0f * M_PI) rotation1 -= 2.0f * M_PI;
+	  float trueVec[2] = {(position[0]-shotPos[0])/dist,(position[1]-shotPos[1])/dist};
+	  float dotProd = trueVec[0]*shotUnitVec[0]+trueVec[1]*shotUnitVec[1];
 
-            float rotation2 = (shotAngle - M_PI/2.0f) - azimuth;
-            if (rotation2 < -1.0f * M_PI) rotation2 += 2.0f * M_PI;
-            if (rotation2 > 1.0f * M_PI) rotation2 -= 2.0f * M_PI;
+	  if (dotProd > 0.97f) {
+	    float rotation;
+	    float rotation1 = (float)((shotAngle + M_PI/2.0) - azimuth);
+	    if (rotation1 < -1.0f * M_PI) rotation1 += (float)(2.0 * M_PI);
+	    if (rotation1 > 1.0f * M_PI) rotation1 -= (float)(2.0 * M_PI);
 
-            if (fabs(rotation1) < fabs(rotation2))
-              rotation = rotation1;
-            else
-              rotation = rotation2;
-            setDesiredSpeed(1.0f);
-            setDesiredAngVel(rotation);
-            evading = true;
-          }
-        }
+	    float rotation2 = (float)((shotAngle - M_PI/2.0) - azimuth);
+	    if (rotation2 < -1.0f * M_PI) rotation2 += (float)(2.0 * M_PI);
+	    if (rotation2 > 1.0f * M_PI) rotation2 -= (float)(2.0 * M_PI);
+
+	    if (fabs(rotation1) < fabs(rotation2))
+	      rotation = rotation1;
+	    else
+	      rotation = rotation2;
+	    setDesiredSpeed(1.0f);
+	    setDesiredAngVel(rotation);
+	    evading = true;
+	  }
+	}
       }
     }
 
@@ -286,8 +296,8 @@ void			RobotPlayer::doUpdateMotion(float dt)
 
       float segmentAzimuth = atan2f(v[1], v[0]);
       float azimuthDiff = segmentAzimuth - azimuth;
-      if (azimuthDiff > M_PI) azimuthDiff -= 2.0f * M_PI;
-      else if (azimuthDiff < -M_PI) azimuthDiff += 2.0f * M_PI;
+      if (azimuthDiff > M_PI) azimuthDiff -= (float)(2.0 * M_PI);
+      else if (azimuthDiff < -M_PI) azimuthDiff += (float)(2.0 * M_PI);
       if (fabs(azimuthDiff) > 0.01f) {
 	// drive backward when target is behind, try to stick to last direction
 	if (drivingForward)
@@ -338,6 +348,13 @@ void			RobotPlayer::restart(const float* pos, float _azimuth)
 
 }
 
+// just use losses - wins
+int			 RobotPlayer::getHandicapScoreBase() const
+{
+  return getLosses() - getWins();
+}
+
+
 float			RobotPlayer::getTargetPriority(const
 							Player* _target) const
 {
@@ -347,7 +364,7 @@ float			RobotPlayer::getTargetPriority(const
 
   // go after closest player
   // FIXME -- this is a pretty stupid heuristic
-  const float worldSize = BZDB.eval(StateDatabase::BZDB_WORLDSIZE);
+  const float worldSize = BZDBCache::worldSize;
   const float* p1 = getPosition();
   const float* p2 = _target->getPosition();
 
@@ -366,7 +383,7 @@ float			RobotPlayer::getTargetPriority(const
     - 0.5f * hypotf(p2[0] - p1[0], p2[1] - p1[1]) / worldSize;
 }
 
-void                    RobotPlayer::setObstacleList(std::vector<BzfRegion*>*
+void		    RobotPlayer::setObstacleList(std::vector<BzfRegion*>*
 						     _obstacleList)
 {
   obstacleList = _obstacleList;
