@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,10 +18,20 @@
 #define	BZF_SERVER_LINK_H
 
 #include "common.h"
+
+#include <string>
+#ifdef HAVE_KRB5
+	#ifdef MAXHOSTNAMELEN
+		#undef MAXHOSTNAMELEN
+	#endif
+#include <krb5.h>
+#endif
+
 #include "global.h"
 #include "Address.h"
 #include "Protocol.h"
 #include "ShotPath.h"
+#include "Flag.h"
 
 class ServerLink {
   public:
@@ -31,7 +41,8 @@ class ServerLink {
 			Rejected = 2,
 			BadVersion = 3,
 			Hungup = 4,		// only used by Winsock
-			CrippledVersion = 5
+			CrippledVersion = 5,
+			Refused = 6
     };
 
     enum Abilities {
@@ -47,6 +58,7 @@ class ServerLink {
 			~ServerLink();
 
     State		getState() const;
+    const std::string&	getRejectionMessage() { return rejectionMessage; }
     int			getSocket() const;	// file descriptor actually
     const PlayerId&	getId() const;
     const char*		getVersion() const;
@@ -57,13 +69,21 @@ class ServerLink {
 						int millisecondsToBlock = 0);
 
     void		sendEnter(PlayerType, TeamColor,
-					const char* name, const char* email);
+				  const char* name, const char* email, const char* token);
+    bool		readEnter(std::string& reason,
+				  uint16_t& code, uint16_t& rejcode);
+
     void		sendCaptureFlag(TeamColor);
     void		sendGrabFlag(int flagIndex);
     void		sendDropFlag(const float* position);
-    void		sendKilled(const PlayerId&, int reason, int shotId);
+#ifdef HAVE_KRB5
+    void		sendKerberosTicket(const char      *principal,
+					   const krb5_data *ticket);
+#endif
+    void		sendKilled(const PlayerId&, int reason,
+				   int shotId, const FlagType* flag, int phydrv);
   // FIXME -- This is very ugly, but required to build bzadmin with gcc 2.9.5.
-  //          It should be changed to something cleaner.
+  //	  It should be changed to something cleaner.
 #ifndef BUILDING_BZADMIN
     void		sendPlayerUpdate(Player*);
 #endif
@@ -74,6 +94,7 @@ class ServerLink {
     void		sendTransferFlag(const PlayerId&, const PlayerId&);
     void		sendNewRabbit();
     void		sendPaused(bool paused);
+    void		sendAutoPilot(bool autopilot);
     void		sendUDPlinkRequest();
 
     static ServerLink*	getServer(); // const
@@ -94,6 +115,12 @@ class ServerLink {
     char		version[9];
     static ServerLink*	server;
     int			server_abilities;
+
+    std::string	 rejectionMessage;
+
+    int		 udpLength;
+    char	       *udpBufferPtr;
+    char		ubuf[MaxPacketLen];
 };
 
 #define SEND 1
