@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,37 +10,38 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786 )
-#endif
-
-// class interface header
+/* interface header */
 #include "CustomLink.h"
 
-// system headers
+/* system implementation headers */
 #include <string.h>
+#include <string>
 
 
 CustomLink::CustomLink()
 {
-  from = 0;
-  to = 0;
+  from = "";
+  to = "";
 }
 
 
 bool CustomLink::read(const char *cmd, std::istream& input)
 {
-  if (strcmp(cmd, "from") == 0)
+  std::string to_string;
+  if (strcmp(cmd, "from") == 0) {
     input >> from;
-  else if (strcmp(cmd, "to") == 0)
+  }
+  else if (strcmp(cmd, "to") == 0) {
     input >> to;
-  else
+  }
+  else {
     return WorldFileObject::read(cmd, input);
+  }
   return true;
 }
 
 
-void CustomLink::write(WorldInfo *world) const
+void CustomLink::writeToWorld(WorldInfo *world) const
 {
   world->addLink(from, to);
 }
