@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,31 +10,27 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _MSC_VER
-#pragma warning( 4: 4786 )
-#endif
-
-// class interface header
+/* interface header */
 #include "CustomWeapon.h"
 
-// bzfs-specific headers
-#include "WorldWeapons.h"
-
-// system headers
+/* system headers */
 #include <sstream>
+#include <string>
+#include <math.h>
 
-// external dependancies
-extern WorldWeapons  wWeapons;
-
+/* local implementation headers */
+#include "WorldWeapons.h"
 
 TimeKeeper CustomWeapon::sync = TimeKeeper::getCurrent();
 
+const float CustomWeapon::minWeaponDelay = 0.1f;
 
 CustomWeapon::CustomWeapon()
 {
   pos[0] = pos[1] = pos[2] = 0.0f;
   rotation = 0.0f;
   size[0] = size[1] = size[2] = 1.0f;
+  tilt = 0.0f;
   initdelay = 10.0f;
   delay.push_back(10.0f);
   type = Flags::Null;
@@ -54,7 +50,13 @@ bool CustomWeapon::read(const char *cmd, std::istream& input) {
     std::istringstream  parms(args);
 
     while (parms >> d) {
-      delay.push_back(d);
+      if (d < minWeaponDelay) {
+	std::cout << "skipping weapon delay of " << d << " seconds" << std::endl;
+	continue;
+      }
+      else {
+	delay.push_back(d);
+      }
     }
     input.putback('\n');
     if (delay.size() == 0)
@@ -67,17 +69,27 @@ bool CustomWeapon::read(const char *cmd, std::istream& input) {
     if (type == NULL)
       return false;
   }
-  else if (!WorldFileObstacle::read(cmd, input))
-      return false;
+  else if (strcmp(cmd, "tilt") == 0) {
+    if (!(input >> tilt)) {
+      std::cout << "weapon tilt requires a value" << std::endl;
+    }
+    // convert to radians
+    tilt = (float)(tilt * (M_PI / 180.0));
+  }
+  else if (!WorldFileLocation::read(cmd, input)) {
+    return false;
+  }
 
   return true;
 }
 
 
-void CustomWeapon::write(WorldInfo*) const {
-  wWeapons.add(type, pos, rotation, initdelay, delay, sync);
+void CustomWeapon::writeToWorld(WorldInfo* world) const
+{
+  world->addWeapon(type, pos, rotation, tilt, initdelay, delay, sync);
 }
 
+
 // Local variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
