@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -13,36 +13,42 @@
 #ifndef __CUSTOMWEAPON_H__
 #define __CUSTOMWEAPON_H__
 
-// system headers
+#include "common.h"
+
+/* system interface headers */
 #include <iostream>
 #include <vector>
 
-// common-interface headers
+/* common interface headers */
 #include "Flag.h"
 #include "TimeKeeper.h"
 
-// bzfs-specific headers
-#include "WorldFileObstacle.h"
+/* local interface headers */
+#include "WorldFileLocation.h"
 #include "WorldInfo.h"
 
 
-class CustomWeapon : public WorldFileObstacle {
+class CustomWeapon : public WorldFileLocation {
   public:
     CustomWeapon();
-  virtual bool read(const char *cmd, std::istream&);
-    virtual void write(WorldInfo*) const;
+    virtual bool read(const char *cmd, std::istream&);
+    virtual void writeToWorld(WorldInfo*) const;
+    virtual bool usesGroupDef() { return false; }
+
+    static const float minWeaponDelay;
 
   protected:
     float initdelay;
     std::vector<float> delay;
     FlagType *type;
+    float tilt;
     static TimeKeeper sync;
 };
 
 #endif  /* __CUSTOMWEAPON_H__ */
 
 // Local variables: ***
-// mode:C++ ***
+// mode: C++ ***
 // tab-width: 8 ***
 // c-basic-offset: 2 ***
 // indent-tabs-mode: t ***
