@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -14,23 +14,56 @@
 #pragma warning( 4: 4786 )
 #endif
 
+#include "common.h"
+
 // interface header
 #include "WorldFileObject.h"
 
+// system headers
+#include <string>
+#include <iostream>
+#include <vector>
+
+WorldFileObject::WorldFileObject()
+{
+  name = "";
+}
+
 
 bool WorldFileObject::read(const char *cmd, std::istream& input)
 {
-  std::string name;
   if (strcasecmp(cmd, "name") == 0) {
-    //This is currently unused, but can be used for documentation purposes
     input >> name;
     return true;
   }
   return false;
 }
 
+
+void WorldFileObject::writeToWorld(WorldInfo*) const
+{
+  std::cout << "ERROR: writeToWorld() called improperly" << std::endl;
+  return;
+}
+
+
+void WorldFileObject::writeToManager() const
+{
+  std::cout << "ERROR: writeToManager() called improperly" << std::endl;
+  return;
+}
+
+
+void WorldFileObject::writeToGroupDef(GroupDefinition*) const
+{
+  std::cout << "ERROR: writeToGroupDef() called improperly" << std::endl;
+  return;
+}
+
+
 /** delete all of the world file objects from a vector list
  */
+
 void emptyWorldFileObjectList(std::vector<WorldFileObject*>& wlist)
 {
   const int n = wlist.size();
@@ -40,6 +73,7 @@ void emptyWorldFileObjectList(std::vector<WorldFileObject*>& wlist)
   wlist.clear();
 }
 
+
 // Local variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
