@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -15,18 +15,28 @@
 // system headers
 #include <iostream>
 #include <vector>
+#include <string>
 
-// bzfs-specific headers
-#include "WorldInfo.h"
+
+class WorldInfo;
+class GroupDefinition;
 
 
 class WorldFileObject {
-public:
-  WorldFileObject() { }
-  virtual ~WorldFileObject() { }
+  public:
+    WorldFileObject();
+    virtual ~WorldFileObject() { }
 
-  virtual bool read(const char *cmd, std::istream&);
-  virtual void write(WorldInfo*) const = 0;
+    virtual bool read(const char *cmd, std::istream&);
+
+    virtual bool usesManager() { return false; }
+    virtual bool usesGroupDef() { return true; }
+    virtual void writeToWorld(WorldInfo*) const;
+    virtual void writeToManager() const;
+    virtual void writeToGroupDef(GroupDefinition*) const;
+
+  protected:
+    std::string name;
 };
 
 
