@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,11 +10,18 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
+
+// interface header
 #include "ErrorHandler.h"
+
+// system headers
 #include <stdio.h>
 #include <stdarg.h>
+#include <vector>
+#include <string>
+
+// local implementation headers
 #include "bzfio.h"
-#include "common.h"
 #include "BundleMgr.h"
 #include "Bundle.h"
 
@@ -40,7 +47,7 @@ void			printError(const std::string &fmt, const std::vector<std::string> *parms)
     msg = pBdl->getLocalString(fmt);
 
   if (errorCallback) (*errorCallback)(msg.c_str());
-#if defined(_MSC_VER)
+#if defined(_WIN32)
   else { OutputDebugString(msg.c_str()); OutputDebugString("\n"); }
 #else
   else std::cerr << msg << std::endl;
