@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -14,9 +14,18 @@
 #pragma warning(4:4503)
 #endif
 
+// interface header
 #include "KeyManager.h"
+
+// system headers
 #include <assert.h>
 #include <ctype.h>
+#include <string.h> // strstr, etc
+#include <string>   // std::string
+#include <vector>
+
+// local implementation headers
+#include "BzfEvent.h"
 
 // initialize the singleton
 template <>
@@ -34,7 +43,25 @@ const char*		KeyManager::buttonNames[] = {
   "Page Up",
   "Page Down",
   "Insert",
+  "Backspace",
   "Delete",
+  "Kp0",
+  "Kp1",
+  "Kp2",
+  "Kp3",
+  "Kp4",
+  "Kp5",
+  "Kp6",
+  "Kp7",
+  "Kp8",
+  "Kp9",
+  "Kp_Period",
+  "Kp_Divide",
+  "Kp_Multiply",
+  "Kp_Minus",
+  "Kp_Plus",
+  "Kp_Enter",
+  "Kp_Equals",
   "F1",
   "F2",
   "F3",
@@ -47,9 +74,24 @@ const char*		KeyManager::buttonNames[] = {
   "F10",
   "F11",
   "F12",
+  "Help",
+  "Print",
+  "Sysreq",
+  "Break",
+  "Menu",
+  "Power",
+  "Euro",
+  "Undo",
   "Left Mouse",
   "Middle Mouse",
   "Right Mouse",
+  "Wheel Up",
+  "Wheel Down",
+  "Mouse Button 6",
+  "Mouse Button 7",
+  "Mouse Button 8",
+  "Mouse Button 9",
+  "Mouse Button 10",
   "Joystick Button 1",
   "Joystick Button 2",
   "Joystick Button 3",
@@ -60,7 +102,7 @@ const char*		KeyManager::buttonNames[] = {
   "Joystick Button 8",
   "Joystick Button 9",
   "Joystick Button 10",
-  "LastButton"
+  "LastButton"  // should always be last item listed
 };
 const char*		KeyManager::asciiNames[][2] = {
   { "Tab",		"\t" },
@@ -121,6 +163,34 @@ void			KeyManager::unbind(const BzfKeyEvent& key,
   notify(key, press, "");
 }
 
+void			KeyManager::unbindCommand(const char* command)
+{
+  EventToCommandMap::iterator index;
+  EventToCommandMap::iterator deleteme;
+
+  index = pressEventToCommand.begin();
+  while (index != pressEventToCommand.end()) {
+    if (index->second == command) {
+      deleteme = index;
+      index++;
+      unbind(deleteme->first, true);
+    } else {
+      index++;
+    }
+  }
+
+  index = releaseEventToCommand.begin();
+  while (index != releaseEventToCommand.end()) {
+    if (index->second == command) {
+      deleteme = index;
+      index++;
+      unbind(deleteme->first, false);
+    } else {
+      index++;
+    }
+  }
+}
+
 std::string		KeyManager::get(const BzfKeyEvent& key,
 					bool press) const
 {
@@ -177,7 +247,7 @@ std::string		KeyManager::keyEventToString(
     case ' ':
       return name + "Space";
     default:
-      if (!isspace(key.ascii))
+      if (!isspace((unsigned char)key.ascii))
 	return name + std::string(&key.ascii, 1);
       return name + "???";
   }
