@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,10 +10,22 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#include <math.h>
+// bzflag common header
 #include "common.h"
+
+// interface header
 #include "QuadWallSceneNode.h"
+
+// system headers
+#include <math.h>
+
+// common implementation headers
+#include "Intersect.h"
+
+// local implementation headers
 #include "ViewFrustum.h"
+
+// FIXME (SceneRenderer.cxx is in src/bzflag)
 #include "SceneRenderer.h"
 
 //
@@ -100,8 +112,24 @@ void			QuadWallSceneNode::Geometry::render()
 {
   wall->setColor();
   glNormal3fv(normal);
-  if (style >= 2) drawVT();
-  else drawV();
+  if (style >= 2) {
+    drawVT();
+  } else {
+    drawV();
+  }
+
+  return;
+}
+
+void			QuadWallSceneNode::Geometry::renderShadow()
+{
+  int last = (ds + 1) * dt;
+  glBegin(GL_TRIANGLE_STRIP);
+  glVertex3fv(vertex[last]);
+  glVertex3fv(vertex[0]);
+  glVertex3fv(vertex[last + ds]);
+  glVertex3fv(vertex[ds]);
+  glEnd();
 }
 
 void			QuadWallSceneNode::Geometry::drawV() const
@@ -114,6 +142,11 @@ void			QuadWallSceneNode::Geometry::drawVT() const
   RENDER(EMITVT)
 }
 
+const GLfloat*		QuadWallSceneNode::Geometry::getVertex(int i) const
+{
+  return vertex[i];
+}
+
 //
 // QuadWallSceneNode
 //
@@ -275,6 +308,12 @@ void			QuadWallSceneNode::init(const GLfloat base[3],
 				uRepeats, vRepeats);
   }
 
+  // record extents info
+  for (int i = 0; i < 4; i++) {
+    const float* point = getVertex(i);
+    extents.expandToPoint(point);
+  }
+
   // record LOD info
   setNumLODs(numLevels, areas);
 }
@@ -312,7 +351,7 @@ void			QuadWallSceneNode::addRenderNodes(
 {
   const int lod = pickLevelOfDetail(renderer);
   nodes[lod]->setStyle(getStyle());
-  renderer.addRenderNode(nodes[lod], &getGState());
+  renderer.addRenderNode(nodes[lod], getWallGState());
 }
 
 void			QuadWallSceneNode::addShadowNodes(
@@ -321,6 +360,35 @@ void			QuadWallSceneNode::addShadowNodes(
   renderer.addShadowNode(shadowNode);
 }
 
+bool		    QuadWallSceneNode::inAxisBox(const Extents& exts) const
+{
+  if (!extents.touches(exts)) {
+    return false;
+  }
+
+  // NOTE: inefficient
+  float vertices[4][3];
+  memcpy (vertices[0], nodes[0]->getVertex(0), sizeof(float[3]));
+  memcpy (vertices[1], nodes[0]->getVertex(1), sizeof(float[3]));
+  memcpy (vertices[2], nodes[0]->getVertex(2), sizeof(float[3]));
+  memcpy (vertices[3], nodes[0]->getVertex(3), sizeof(float[3]));
+
+  return testPolygonInAxisBox (4, vertices, getPlane(), exts);
+}
+
+int		     QuadWallSceneNode::getVertexCount () const
+{
+  return 4;
+}
+
+const GLfloat*	  QuadWallSceneNode::getVertex (int vertex) const
+{
+  // re-map these to a counter-clockwise order
+  const int order[4] = {0, 1, 3, 2};
+  return nodes[0]->getVertex(order[vertex]);
+}
+
+
 // Local Variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
