@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,14 +10,25 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#include <math.h>
+// bzflag common header
 #include "common.h"
+
+// interface header
 #include "SphereSceneNode.h"
-#include "ViewFrustum.h"
-#include "SceneRenderer.h"
+
+// system headers
+#include <math.h>
+
+// common implementation headers
 #include "StateDatabase.h"
 #include "BZDBCache.h"
 
+// local implementation headers
+#include "ViewFrustum.h"
+
+// FIXME (SceneRenderer.cxx is in src/bzflag)
+#include "SceneRenderer.h"
+
 //
 // SphereSceneNode
 //
@@ -56,9 +67,7 @@ void			SphereSceneNode::setColor(
   color[1] = g;
   color[2] = b;
   color[3] = a;
-  const bool oldTransparent = transparent;
   transparent = (color[3] != 1.0f);
-  if (oldTransparent != transparent) forceNotifyStyleChange();
 }
 
 void			SphereSceneNode::setColor(const GLfloat* rgba)
@@ -67,9 +76,7 @@ void			SphereSceneNode::setColor(const GLfloat* rgba)
   color[1] = rgba[1];
   color[2] = rgba[2];
   color[3] = rgba[3];
-  const bool oldTransparent = transparent;
   transparent = (color[3] != 1.0f);
-  if (oldTransparent != transparent) forceNotifyStyleChange();
 }
 
 void			SphereSceneNode::move(const GLfloat pos[3],
@@ -103,10 +110,9 @@ SceneNode**		SphereSceneNode::getParts(int& numParts)
   return (SceneNode**)parts;
 }
 
-void			SphereSceneNode::notifyStyleChange(
-				const SceneRenderer&)
+void			SphereSceneNode::notifyStyleChange()
 {
-  lighting = BZDB.isTrue("lighting");
+  lighting = BZDBCache::lighting;
   OpenGLGStateBuilder builder(gstate);
   if (BZDBCache::blend && transparent) {
     builder.setBlending(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -176,9 +182,9 @@ SphereSceneNode::SphereRenderNode::SphereRenderNode(
     // high resolution sphere
     int i, j;
     for (i = 0; i <= SphereRes; i++) {
-      const float phi = M_PI * (0.5f - float(i) / SphereRes);
+      const float phi = (const float)(M_PI * (0.5f - double(i) / SphereRes));
       for (j = 0; j < NumSlices; j++) {
-	const float theta = 2.0f * M_PI * float(j) / NumSlices;
+	const float theta = (const float)(2.0 * M_PI * double(j) / NumSlices);
 	geom[NumSlices * i + j][0] = cosf(theta) * cosf(phi);
 	geom[NumSlices * i + j][1] = sinf(theta) * cosf(phi);
 	geom[NumSlices * i + j][2] = sinf(phi);
@@ -187,9 +193,9 @@ SphereSceneNode::SphereRenderNode::SphereRenderNode(
 
     // low resolution sphere
     for (i = 0; i <= SphereLowRes; i++) {
-      const float phi = M_PI * (0.5f - float(i) / SphereLowRes);
+      const float phi = (const float)(M_PI * (0.5 - double(i) / SphereLowRes));
       for (j = 0; j < SphereLowRes; j++) {
-	const float theta = 2.0f * M_PI * float(j) / SphereLowRes;
+	const float theta = (const float)(2.0 * M_PI * double(j) / SphereLowRes);
 	lgeom[SphereLowRes * i + j][0] = cosf(theta) * cosf(phi);
 	lgeom[SphereLowRes * i + j][1] = sinf(theta) * cosf(phi);
 	lgeom[SphereLowRes * i + j][2] = sinf(phi);
@@ -339,7 +345,7 @@ void			SphereFragmentSceneNode::move()
   setCenter(pSphere[0] + pRadius * vertex[0],
 	    pSphere[1] + pRadius * vertex[1],
 	    pSphere[2] + pRadius * vertex[2]);
-  setRadius(4.0f * M_PI * M_PI * pSphere[3] /
+  setRadius((GLfloat)(4.0 * M_PI * M_PI * pSphere[3]) /
 			GLfloat(SphereLowRes * SphereLowRes));
 }
 
@@ -383,7 +389,7 @@ const GLfloat*		SphereFragmentSceneNode::FragmentRenderNode::
 }
 
 const GLfloat*		SphereFragmentSceneNode::FragmentRenderNode::
-				getPosition()
+				getPosition() const
 {
   return sceneNode->getSphere();
 }
