@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -15,35 +15,40 @@
 
 #include "MediaFile.h"
 
+/** This ABC represents an image file. It has subclasses for different image
+    formats. */
 class ImageFile : public MediaFile {
 public:
-  // close the image file.  this does *not* destroy the stream.
+  /** Close the image file.  This does *not* destroy the stream. */
   virtual ~ImageFile();
 
   // note -- all concrete ImageFile types should have a method to
   // return the default file extension for files in the format:
   // static std::string getExtension();
 
-  // pixels are stored I, IA, RGB, or RGBA, depending on the number
-  // of channels.  rows are stored left to right, bottom to top.
-  // buffer must be at least getNumChannels() * getWidth() * getHeight()
-  // bytes.
-  virtual bool		read(void* buffer) = 0;
+  /** Pixels are stored I, IA, RGB, or RGBA, depending on the number
+      of channels.  Rows are stored left to right, bottom to top.
+      Buffer must be at least getNumChannels() * getWidth() * getHeight()
+      bytes. */
+  virtual bool read(void* buffer) = 0;
 
-  // returns true if the stream was successfully opened as an image file
-  bool			isOpen() const;
+  /** Returns true if the stream was successfully opened as an image file. */
+  bool isOpen() const;
 
-  // get information about the image file.  channels are 8 bits.
+  /** Get the number of channels in the image file. Channels are 8 bits. */
   int			getNumChannels() const;
+
+  /** Get the width of the image file. */
   int			getWidth() const;
+
+  /** Get the height of the image file. */
   int			getHeight() const;
 
 protected:
   ImageFile(std::istream*);
 
-  // save info about the stream.  called by the derived c'tor.
-  // don't call this if the stream is not an audio file.
-  void			init(int numChannels, int width, int height);
+  /** Save info about the stream.  Called by the derived c'tor. */
+  void init(int numChannels, int width, int height);
 
 private:
   bool			open;
