@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -10,11 +10,6 @@
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-#ifdef _WIN32
-#include <winsock2.h>
-#include <ws2tcpip.h>
-#endif
-
 #include <string.h>
 #include "common.h"
 #include "Pack.h"
@@ -22,6 +17,45 @@
 
 #define	ADV(_b, _t)	((void*)(((char*)(_b)) + sizeof(_t)))
 
+
+//
+// Buffer Overrun Checks
+//
+
+static bool Error = false;
+static bool ErrorChecking = false;
+static unsigned int Length = 0;
+
+void nboUseErrorChecking(bool checking)
+{
+  ErrorChecking = checking;
+}
+
+bool nboGetBufferError()
+{
+  return Error;
+}
+
+void nboClearBufferError()
+{
+  Error = false;
+}
+
+void nboSetBufferLength(unsigned int length)
+{
+  Length = length;
+}
+
+unsigned int nboGetBufferLength()
+{
+  return Length;
+}
+
+
+//
+// Packers
+//
+
 void*			nboPackUByte(void* b, uint8_t v)
 {
   ::memcpy(b, &v, sizeof(uint8_t));
@@ -86,14 +120,45 @@ void*			nboPackString(void* b, const void* m, int len)
   return (void*)((char*)b + len);
 }
 
+void*			nboPackStdString(void* b, const std::string& str)
+{
+  uint32_t strSize = str.size();
+  b = nboPackUInt(b, strSize);
+  b = nboPackString(b, str.c_str(), strSize);
+  return b;
+}
+
+
+//
+// UnPackers
+//
+
 void*			nboUnpackUByte(void* b, uint8_t& v)
 {
+  if (ErrorChecking) {
+    if (Length < sizeof(uint8_t)) {
+      Error = true;
+      v = 0;
+      return b;
+    } else {
+      Length -= sizeof(uint8_t);
+    }
+  }
   ::memcpy(&v, b, sizeof(uint8_t));
   return ADV(b, uint8_t);
 }
 
 void*			nboUnpackShort(void* b, int16_t& v)
 {
+  if (ErrorChecking) {
+    if (Length < sizeof(int16_t)) {
+      Error = true;
+      v = 0;
+      return b;
+    } else {
+      Length -= sizeof(int16_t);
+    }
+  }
   int16_t x;
   ::memcpy(&x, b, sizeof(int16_t));
   v = (int16_t)ntohs(x);
@@ -102,6 +167,15 @@ void*			nboUnpackShort(void* b, int16_t& v)
 
 void*			nboUnpackInt(void* b, int32_t& v)
 {
+  if (ErrorChecking) {
+    if (Length < sizeof(int32_t)) {
+      Error = true;
+      v = 0;
+      return b;
+    } else {
+      Length -= sizeof(int32_t);
+    }
+  }
   int32_t x;
   ::memcpy(&x, b, sizeof(int32_t));
   v = (int32_t)ntohl(x);
@@ -110,6 +184,15 @@ void*			nboUnpackInt(void* b, int32_t& v)
 
 void*			nboUnpackUShort(void* b, uint16_t& v)
 {
+  if (ErrorChecking) {
+    if (Length < sizeof(uint16_t)) {
+      Error = true;
+      v = 0;
+      return b;
+    } else {
+      Length -= sizeof(uint16_t);
+    }
+  }
   uint16_t x;
   ::memcpy(&x, b, sizeof(uint16_t));
   v = (uint16_t)ntohs(x);
@@ -118,6 +201,15 @@ void*			nboUnpackUShort(void* b, uint16_t& v)
 
 void*			nboUnpackUInt(void* b, uint32_t& v)
 {
+  if (ErrorChecking) {
+    if (Length < sizeof(uint32_t)) {
+      Error = true;
+      v = 0;
+      return b;
+    } else {
+      Length -= sizeof(uint32_t);
+    }
+  }
   uint32_t x;
   ::memcpy(&x, b, sizeof(uint32_t));
   v = (uint32_t)ntohl(x);
@@ -126,6 +218,15 @@ void*			nboUnpackUInt(void* b, uint32_t& v)
 
 void*			nboUnpackFloat(void* b, float& v)
 {
+  if (ErrorChecking) {
+    if (Length < sizeof(float)) {
+      Error = true;
+      v = 0.0f;
+      return b;
+    } else {
+      Length -= sizeof(float);
+    }
+  }
   // hope that float is a 4 byte IEEE 754 standard encoding
   uint32_t x;
   ::memcpy(&x, b, sizeof(uint32_t));
@@ -136,6 +237,15 @@ void*			nboUnpackFloat(void* b, float& v)
 
 void*			nboUnpackVector(void* b, float *v)
 {
+  if (ErrorChecking) {
+    if (Length < sizeof(float[3])) {
+      Error = true;
+      v[0] = v[1] = v[2] = 0.0f;
+      return b;
+    } else {
+      Length -= sizeof(float[3]);
+    }
+  }
   // hope that float is a 4 byte IEEE 754 standard encoding
   uint32_t data[3];
   ::memcpy( data, b, 3*sizeof(float));
@@ -151,10 +261,46 @@ void*			nboUnpackVector(void* b, float *v)
 void*			nboUnpackString(void* b, void* m, int len)
 {
   if (!m || len == 0) return b;
+  if (ErrorChecking) {
+    if (Length < (unsigned int)len) {
+      Error = true;
+      ((char*)m)[0] = '\0';
+      return b;
+    } else {
+      Length -= len;
+    }
+  }
   ::memcpy(m, b, len);
   return (void*)((char*)b + len);
 }
 
+void*			nboUnpackStdString(void* b, std::string& str)
+{
+  uint32_t strSize;
+  b = nboUnpackUInt(b, strSize);
+  char* buffer = new char[strSize + 1];
+  b = nboUnpackString(b, buffer, strSize);
+  buffer[strSize] = 0;
+  str = buffer;
+  delete[] buffer;
+  if (ErrorChecking && Error) {
+    str = "";
+    return b;
+  }
+  return b;
+}
+
+
+//
+// Utilities
+//
+
+unsigned int nboStdStringPackSize(const std::string& str)
+{
+  return (sizeof(uint32_t) + str.size());
+}
+
+
 // Local Variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
