@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -39,7 +39,8 @@ BzfDisplay::BzfDisplay() : passWidth(640), passHeight(480),
 				numResolutions(0),
 				defaultResolution(-1),
 				currentResolution(-1),
-				resolutions(NULL)
+				resolutions(NULL),
+				modeIndex(-1)
 {
   // do nothing
 }
@@ -111,6 +112,7 @@ bool			BzfDisplay::setResolution(int index)
     return false;
   }
   currentResolution = index;
+  setFullScreenFormat(index);
   return true;
 }
 
@@ -156,6 +158,10 @@ void			BzfDisplay::initResolutions(ResInfo** _resolutions,
   defaultResolution = currentResolution;
 }
 
+void BzfDisplay::setFullScreenFormat(int index) {
+  modeIndex = index;
+};
+
 // Local Variables: ***
 // mode:C++ ***
 // tab-width: 8 ***
