@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -18,7 +18,9 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/time.h>
-#include <bstring.h>
+#ifdef HAVE_BSTRING_H
+#  include <bstring.h>
+#endif
 #include <sys/prctl.h>
 #include <sys/wait.h>
 #include "bzsignal.h"
@@ -81,14 +83,6 @@ double			SGIMedia::stopwatch(bool start)
   }
 }
 
-void			SGIMedia::sleep(float timeInSeconds)
-{
-  struct timeval tv;
-  tv.tv_sec = (long)timeInSeconds;
-  tv.tv_usec = (long)(1.0e6 * (timeInSeconds - floor(timeInSeconds)));
-  select(0, NULL, NULL, NULL, &tv);
-}
-
 bool			SGIMedia::openAudio()
 {
   // don't re-initialize
