@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -11,10 +11,18 @@
  */
 
 #include "WinPlatformFactory.h"
+#ifdef HAVE_SDL
+#include "SDLMedia.h"
+#include "SDLDisplay.h"
+#include "SDLJoystick.h"
+#else
+#include "DXJoystick.h"
+#include "WinMedia.h"
 #include "WinDisplay.h"
 #include "WinVisual.h"
 #include "WinWindow.h"
-#include "WinMedia.h"
+#include "WinJoystick.h"
+#endif
 
 PlatformFactory*	PlatformFactory::getInstance()
 {
@@ -22,7 +30,11 @@ PlatformFactory*	PlatformFactory::getInstance()
   return instance;
 }
 
+#ifdef HAVE_SDL
+SDLWindow*		WinPlatformFactory::window = NULL;
+#else
 WinWindow*		WinPlatformFactory::window = NULL;
+#endif
 
 WinPlatformFactory::WinPlatformFactory()
 {
@@ -34,6 +46,18 @@ WinPlatformFactory::~WinPlatformFactory()
   // do nothing
 }
 
+#ifdef HAVE_SDL
+BzfDisplay*		WinPlatformFactory::createDisplay(
+				const char*, const char*)
+{
+  SDLDisplay* display = new SDLDisplay();
+  if (!display || !display->isValid()) {
+    delete display;
+    return NULL;
+  }
+  return display;
+}
+#else
 BzfDisplay*		WinPlatformFactory::createDisplay(
 				const char* name, const char* videoFormat)
 {
@@ -44,23 +68,56 @@ BzfDisplay*		WinPlatformFactory::createDisplay(
   }
   return display;
 }
+#endif
 
+#ifdef HAVE_SDL
+BzfVisual*		WinPlatformFactory::createVisual(
+				const BzfDisplay* display)
+{
+  return new SDLVisual((const SDLDisplay*)display);
+}
+#else
 BzfVisual*		WinPlatformFactory::createVisual(
 				const BzfDisplay* display)
 {
   return new WinVisual((const WinDisplay*)display);
 }
+#endif
 
+#ifdef HAVE_SDL
+BzfWindow*		WinPlatformFactory::createWindow(
+				const BzfDisplay* display, BzfVisual* visual)
+{
+  window = new SDLWindow((const SDLDisplay*)display, (SDLVisual*)visual);
+  return window;
+}
+#else
 BzfWindow*		WinPlatformFactory::createWindow(
 				const BzfDisplay* display, BzfVisual* visual)
 {
   window = new WinWindow((const WinDisplay*)display, (WinVisual*)visual);
   return window;
 }
+#endif
 
 BzfMedia*		WinPlatformFactory::createMedia()
 {
+#ifdef HAVE_SDL
+  return new SDLMedia();
+#else
   return new WinMedia(window);
+#endif
+}
+
+BzfJoystick*		WinPlatformFactory::createJoystick()
+{
+#if defined(HAVE_SDL)
+  return new SDLJoystick();
+#elif defined(USE_DINPUT)
+  return new DXJoystick();
+#else
+  return new WinJoystick();
+#endif
 }
 
 // Local Variables: ***
