@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -19,7 +19,11 @@
 
 #include "PlatformFactory.h"
 
-class WinWindow;
+#ifdef HAVE_SDL
+  class SDLWindow;
+#else
+  class WinWindow;
+#endif
 
 class WinPlatformFactory : public PlatformFactory {
   public:
@@ -30,6 +34,7 @@ class WinPlatformFactory : public PlatformFactory {
 				const char* videoFormat);
     BzfVisual*		createVisual(const BzfDisplay*);
     BzfWindow*		createWindow(const BzfDisplay*, BzfVisual*);
+    BzfJoystick*	createJoystick();
 
   private:
 			WinPlatformFactory(const WinPlatformFactory&);
@@ -38,7 +43,11 @@ class WinPlatformFactory : public PlatformFactory {
     BzfMedia*		createMedia();
 
   private:
+#ifdef HAVE_SDL
+    static SDLWindow*	window;
+#else
     static WinWindow*	window;
+#endif
 };
 
 #endif // BZF_WINPLATFORM_FACTORY_H
