@@ -1,5 +1,5 @@
 /* bzflag
- * Copyright (c) 1993 - 2004 Tim Riker
+ * Copyright (c) 1993 - 2005 Tim Riker
  *
  * This package is free software;  you can redistribute it and/or
  * modify it under the terms of the license found in the file
@@ -31,19 +31,6 @@ SceneDatabase::~SceneDatabase()
   // do nothing
 }
 
-//
-// SceneIterator
-//
-
-SceneIterator::SceneIterator()
-{
-  // do nothing
-}
-
-SceneIterator::~SceneIterator()
-{
-  // do nothing
-}
 
 // Local Variables: ***
 // mode:C++ ***
